@@ -142,7 +142,7 @@ public class RssAction implements AJAXActionService {
             List<URL> urls = getUrls(request);
             feeds = getAcceptedFeeds(urls, warnings);
         } catch (IllegalArgumentException | MalformedURLException e) {
-            throw AjaxExceptionCodes.IMVALID_PARAMETER.create(e, e.getMessage());
+            throw AjaxExceptionCodes.INVALID_PARAMETER.create(e, e.getMessage());
         } catch (JSONException e) {
             throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
         }
@@ -281,7 +281,7 @@ public class RssAction implements AJAXActionService {
         List<SyndFeed> feeds = new LinkedList<SyndFeed>();
 
         for (URL url : urls) {
-            if (RssProperties.isDenied(url.toString())) {
+            if (RssProperties.isDenied(url.getProtocol(), url.getHost(), url.getPort())) {
                 final OXException oxe = RssExceptionCodes.RSS_CONNECTION_ERROR.create(url.toString());
                 warnings.add(oxe);
                 continue;
@@ -352,7 +352,7 @@ public class RssAction implements AJAXActionService {
             } catch (IllegalArgumentException e) {
                 String exceptionMessage = e.getMessage();
                 if (!"Invalid document".equals(exceptionMessage)) {
-                    throw AjaxExceptionCodes.IMVALID_PARAMETER.create(e, exceptionMessage);
+                    throw AjaxExceptionCodes.INVALID_PARAMETER.create(e, exceptionMessage);
                 }
                 // There is no parser for current document
                 LOG.warn("Could not load RSS feed from: {}", url);
